@@ -46,7 +46,7 @@ class APIView(View):
             return APIView.AUTH_METHODS.Token
 
     def signature_key(self, *args, **kwargs):
-        return self.request.META.get('HTTP_X_REQUEST_SIGNATURE', None)
+        return self.request.META.get('HTTP_X_REQUEST_SIGNATURE', '')
 
     def signature_key_class(self, *args, **kwargs):
         key_class_path = getattr(settings, SIGNATURE_KEY_CLASS, None)
@@ -123,6 +123,9 @@ class APIView(View):
             'error': error_obj.message,
         })
 
+    def post_handle(self, *args, **kwargs):
+        self.response['Content-Type'] = 'application/json'
+
 
 class DevAPIView(APIView):
     def only_accept_https(self, *args, **kwargs):
